@@ -67,16 +67,16 @@ func TestGuessDotfilesRepoURL(t *testing.T) {
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
-			arg:                  "sr.ht/~user",
-			expectedHTTPRepoURL:  "https://user@git.sr.ht/~user/dotfiles",
-			expectedHTTPUsername: "user",
-			expectedSSHRepoURL:   "git@git.sr.ht:~user/dotfiles",
+			arg:                  "sr.ht/~user_name",
+			expectedHTTPRepoURL:  "https://user_name@git.sr.ht/~user_name/dotfiles",
+			expectedHTTPUsername: "user_name",
+			expectedSSHRepoURL:   "git@git.sr.ht:~user_name/dotfiles",
 		},
 		{
-			arg:                  "sr.ht/~user/dots",
-			expectedHTTPRepoURL:  "https://user@git.sr.ht/~user/dots",
-			expectedHTTPUsername: "user",
-			expectedSSHRepoURL:   "git@git.sr.ht:~user/dots",
+			arg:                  "sr.ht/~user_name/dots",
+			expectedHTTPRepoURL:  "https://user_name@git.sr.ht/~user_name/dots",
+			expectedHTTPUsername: "user_name",
+			expectedSSHRepoURL:   "git@git.sr.ht:~user_name/dots",
 		},
 		{
 			arg:                  "user",
